"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const util_1 = require("util");
const utils_1 = require("./utils");
const execFileAsync = util_1.promisify(child_process_1.execFile);
async function tagExists(tagName) {
    try {
        const { stdout } = await execFileAsync('git', ['tag', '-l', tagName]);
        return stdout.split(/[\r\n]+/).includes(tagName);
    }
    catch (error) {
        throw new Error(`tagExists() Error: ${error}`);
    }
}
exports.tagExists = tagExists;
async function isHeadTag(tagName) {
    try {
        const { stdout } = await execFileAsync('git', [
            'tag',
            '-l',
            tagName,
            '--points-at',
            'HEAD',
        ]);
        return stdout.split(/[\r\n]+/).includes(tagName);
    }
    catch (error) {
        throw new Error(`isHeadTag() Error: ${error}`);
    }
}
exports.isHeadTag = isHeadTag;
async function setTag(tagName, { debug = false, dryRun = false, } = {}) {
    try {
        if (debug) {
            utils_1.printVerbose(`> git tag ${tagName}`);
        }
        if (!dryRun) {
            await execFileAsync('git', ['tag', tagName]);
        }
    }
    catch (error) {
        throw new Error(`setTag() Error: ${error}`);
    }
}
exports.setTag = setTag;
async function push(src, { repository = 'origin', debug = false, dryRun = false, } = {}) {
    try {
        if (debug) {
            utils_1.printVerbose(`> git push ${repository} ${src}`);
        }
        if (!dryRun) {
            await execFileAsync('git', ['push', repository, src]);
        }
    }
    catch (error) {
        throw new Error(`push() Error: ${error}`);
    }
}
exports.push = push;
//# sourceMappingURL=git.js.map