"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const git_1 = require("./git");
const utils_1 = require("./utils");
async function getTagVersionName() {
    const projectPkgPath = path_1.default.join(process.cwd(), 'package.json');
    const projectPkgData = await utils_1.readJSONFile(projectPkgPath);
    if (utils_1.isPkgData(projectPkgData)) {
        return `v${projectPkgData.version}`;
    }
    throw new Error('Failed to find version tag name.');
}
async function gitTagAlreadyExists(versionTagName, opts) {
    if (!(await git_1.isHeadTag(versionTagName))) {
        throw new Error(`Git tag '${versionTagName}' already exists`);
    }
    if (opts.verbose) {
        utils_1.printVerbose(`> #git tag ${versionTagName}\n  # tag '${versionTagName}' already exists`);
    }
}
async function main(opts) {
    if (opts.dryRun) {
        console.error('Dry Run enabled');
        opts.verbose = true;
    }
    const versionTagName = await getTagVersionName();
    if (await git_1.tagExists(versionTagName)) {
        await gitTagAlreadyExists(versionTagName, opts);
    }
    else {
        await git_1.setTag(versionTagName, {
            debug: opts.verbose,
            dryRun: opts.dryRun,
        });
    }
    if (opts.push) {
        await git_1.push(versionTagName, {
            debug: opts.verbose,
            dryRun: opts.dryRun,
        });
    }
}
async function default_1(opts = {}) {
    try {
        await main(opts);
    }
    finally {
        utils_1.endPrintVerbose();
    }
}
exports.default = default_1;
//# sourceMappingURL=index.js.map