"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const readFileAsync = util_1.promisify(fs_1.default.readFile);
function isObject(value) {
    return typeof value === 'object' && value !== null;
}
exports.isObject = isObject;
function relativePath(pathStr) {
    const relativePathStr = path_1.default.relative(process.cwd(), pathStr);
    return path_1.default.isAbsolute(relativePathStr) || relativePathStr.startsWith('.')
        ? relativePathStr
        : `.${path_1.default.sep}${relativePathStr}`;
}
exports.relativePath = relativePath;
function isPkgData(value) {
    if (isObject(value)) {
        return typeof value.version === 'string';
    }
    return false;
}
exports.isPkgData = isPkgData;
async function readJSONFile(filepath) {
    try {
        const dataText = await readFileAsync(filepath, 'utf8');
        try {
            return JSON.parse(dataText);
        }
        catch (error) {
            throw new Error(`Invalid JSON: ${relativePath(filepath)}`);
        }
    }
    catch (error) {
        throw new Error(`Could not read file: ${relativePath(filepath)}`);
    }
}
exports.readJSONFile = readJSONFile;
let isPrintedVerbose = false;
function printVerbose(message) {
    if (!isPrintedVerbose) {
        console.error(`\n${message}`);
        isPrintedVerbose = true;
    }
    else {
        console.error(message);
    }
}
exports.printVerbose = printVerbose;
function endPrintVerbose() {
    if (isPrintedVerbose) {
        console.error();
    }
}
exports.endPrintVerbose = endPrintVerbose;
//# sourceMappingURL=utils.js.map